#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-16Socunxoqo73iQftNkC9u
key:                  coinbase-pro-0.9.3.2-16Socunxoqo73iQftNkC9u
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  ff733216961af7e84b9803227b24865b
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-16Socunxoqo73iQftNkC9u
depends:
    HsOpenSSL-0.11.7.9-5MOpgLVlbfk319dg92uniX
    aeson-2.2.1.0-KqVneGNcXEJ8mIL8sTS8LL
    aeson-casing-0.2.0.0-2xe0GmfNC3a5gFe3VoAZVW
    async-2.2.6-HlTb8qs1wHD7UNlnrqlxTX base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-60xX0n7DtmCDtw9ssgqtp2 exceptions-0.10.7
    http-api-data-0.6.1-4CrUErqI1Rh3s5OGeVSKxc
    http-client-0.7.19-BuEJUWBQ6l56XQSn4y9UoM
    http-client-tls-0.3.6.4-BbNrBeKX6CaBTffOvDIW0u
    http-streams-0.8.9.9-2sXQpVpqPaRLGFiYuz6VHi
    http-types-0.12.4-GbnA9GBjJLTWEnI56wc3O
    io-streams-1.5.2.2-Ju8ZwriFWIeB5oSMpwZIo7
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-8vuuKMF6w9xKjPzP5P4pIh
    servant-0.20.3.0-1oChsSNGpN9CHENbPJtPIu
    servant-client-0.20.3.0-JSWoZmMeT651zyXPjL7TOl
    servant-client-core-0.20.3.0-5uWWcSA10wH87qn9hrel02
    tasty-1.5.2-Lh8BidQyjFlBmEVb0xB88X
    tasty-hunit-0.10.2-2d5v837e0NoDt6MkYfQPQP text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-GbypYyt6woj7SbUlST8rQw
    unordered-containers-0.2.20.1-CeHDQtVso2t69dwLJnxrjh
    uuid-1.3.16.1-LPn4sTwNkraH5uW9TWCwGS
    vector-0.13.2.0-2vFNmgih5WRFjWzUm3LR1R
    websockets-0.12.7.3-6s95Nf4x9H93VmKMiRBXv6
    wuss-2.0.1.6-7eIxiAtF7RMDzYxBx0PrzA

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

